#!/bin/sh
#
# Build the Booke. First assemble the book LaTeX, then build it
# into a PDF.
#

if [ $# != 1 ]; then
    echo "Usage: make.sh <book dir name>"
    exit 1
fi

dir=`pwd`

booke=$dir/$1
builddir=$dir/build
output=dottes.tex

mkdir -p $builddir

cp dottes.tex.header $builddir/$output

# Now, for each tune, add
#
# \addcontentsline{toc}{subsection}{<Tune title>}
# \begin{abc}[name=<filename>]
# ... ABC ...
# \end{abc}

find $booke -name "*.abc" | sort |
    while read filename
    do
        title=`grep "^T:" $filename | head -1 | sed -e "s/^T: *//"`
        name=`basename $filename .abc`
        abcm2ps -j0 +c -n -E -O $builddir/$name.eps $filename
        epstopdf --outfile=$builddir/$name.pdf $builddir/${name}001.eps
        echo "\\\\begin{center}" >> $builddir/$output
        echo "\\\\includegraphics[width=\\\\textwidth]{$name}" >> $builddir/$output
        echo "\\\\addcontentsline{toc}{subsection}{$title}" >> $builddir/$output
        echo "\\\\end{center}" >> $builddir/$output
    done

cat dottes.tex.footer >> $builddir/$output

cd $builddir
pdflatex $output
pdflatex $output

cd $dir
pdflatex dottesona4.tex
